@@ -73,7 +73,7 @@ func (c *client) Draw() {
 	screen.WriteString("\033[0m")
 	screen.WriteString(c.TopBar.Render(c.Width, c.Options["theme"]))
 	screen.WriteString("\n")
-	pageContent := c.PageState.Render(c.Height, c.Width-1, (c.Options["theme"] == "color"))
+	pageContent := c.PageState.Render(c.Height, c.Width-1, getMaxWidth(c.Options), (c.Options["theme"] == "color"))
 	var re *regexp.Regexp
 	if c.Options["theme"] == "inverse" {
 		screen.WriteString("\033[7m")
@@ -146,42 +146,47 @@ func (c *client) TakeControlInput() {
 
 	switch input {
 	case '1', '2', '3', '4', '5', '6', '7', '8', '9', '0':
+		// Quick link
 		if input == '0' {
 			c.goToLink("10")
 		} else {
 			c.goToLink(string(input))
 		}
 	case 'j':
-		// scroll down one line
+		// Scroll down one line
 		c.ClearMessage()
 		c.Scroll(1)
 	case 'k':
-		// scroll up one line
+		// Scroll up one line
 		c.ClearMessage()
 		c.Scroll(-1)
 	case 'q':
-		// quit bombadillo
+		// Quit
 		cui.Exit(0, "")
 	case 'g':
-		// scroll to top
+		// Scroll to top
 		c.ClearMessage()
 		c.Scroll(-len(c.PageState.History[c.PageState.Position].WrappedContent))
 	case 'G':
-		// scroll to bottom
+		// Scroll to bottom
 		c.ClearMessage()
 		c.Scroll(len(c.PageState.History[c.PageState.Position].WrappedContent))
 	case 'd':
-		// scroll down 75%
+		// Scroll down 75%
 		c.ClearMessage()
 		distance := c.Height - c.Height/4
 		c.Scroll(distance)
 	case 'u':
-		// scroll up 75%
+		// Scroll up 75%
 		c.ClearMessage()
 		distance := c.Height - c.Height/4
 		c.Scroll(-distance)
+	case 'U':
+		// Move up a directory for the current host
+		url := c.PageState.History[c.PageState.Position].Location.Full
+		c.Visit(UpOneDir(url))
 	case 'b', 'h':
-		// go back
+		// Go back
 		c.ClearMessage()
 		err := c.PageState.NavigateHistory(-1)
 		if err != nil {
@@ -193,6 +198,7 @@ func (c *client) TakeControlInput() {
 			c.Draw()
 		}
 	case 'R':
+		// Refresh the current page
 		c.ClearMessage()
 		err := c.ReloadPage()
 		if err != nil {
@@ -202,11 +208,11 @@ func (c *client) TakeControlInput() {
 			c.Draw()
 		}
 	case 'B':
-		// open the bookmarks browser
+		// Toggle the bookmark browser
 		c.BookMarks.ToggleOpen()
 		c.Draw()
 	case 'f', 'l':
-		// go forward
+		// Go forward
 		c.ClearMessage()
 		err := c.PageState.NavigateHistory(1)
 		if err != nil {
@@ -218,7 +224,7 @@ func (c *client) TakeControlInput() {
 			c.Draw()
 		}
 	case '\t':
-		// Toggle bookmark browser focus on/off
+		// Toggle bookmark browser focus
 		c.BookMarks.ToggleFocused()
 		c.Draw()
 	case 'n':
@@ -258,7 +264,7 @@ func (c *client) TakeControlInput() {
 		}
 		err = c.NextSearchItem(0)
 		if err != nil {
-			c.PageState.History[c.PageState.Position].WrapContent(c.Width-1,(c.Options["theme"] == "color"))
+			c.PageState.History[c.PageState.Position].WrapContent(c.Width-1,getMaxWidth(c.Options),(c.Options["theme"] == "color"))
 			c.Draw()
 		}
 	case ':', ' ':
@@ -988,7 +994,7 @@ func (c *client) handleGopher(u Url) {
 		} else {
 			pg.FileType = "text"
 		}
-		pg.WrapContent(c.Width-1, (c.Options["theme"] == "color"))
+		pg.WrapContent(c.Width-1, getMaxWidth(c.Options), (c.Options["theme"] == "color"))
 		c.PageState.Add(pg)
 		c.SetPercentRead()
 		c.ClearMessage()
@@ -1015,7 +1021,7 @@ func (c *client) handleGemini(u Url) {
 			u.Mime = capsule.MimeMin
 			pg := MakePage(u, capsule.Content, capsule.Links)
 			pg.FileType = capsule.MimeMaj
-			pg.WrapContent(c.Width-1, (c.Options["theme"] == "color"))
+			pg.WrapContent(c.Width-1, getMaxWidth(c.Options), (c.Options["theme"] == "color"))
 			c.PageState.Add(pg)
 			c.SetPercentRead()
 			c.ClearMessage()
@@ -1081,7 +1087,7 @@ func (c *client) handleLocal(u Url) {
 	if ext == ".jpg" || ext == ".jpeg" || ext == ".gif" || ext == ".png" {
 		pg.FileType = "image"
 	}
-	pg.WrapContent(c.Width-1, (c.Options["theme"] == "color"))
+	pg.WrapContent(c.Width-1, getMaxWidth(c.Options), (c.Options["theme"] == "color"))
 	c.PageState.Add(pg)
 	c.SetPercentRead()
 	c.ClearMessage()
@@ -1097,7 +1103,7 @@ func (c *client) handleFinger(u Url) {
 		return
 	}
 	pg := MakePage(u, content, []string{})
-	pg.WrapContent(c.Width-1, (c.Options["theme"] == "color"))
+	pg.WrapContent(c.Width-1, getMaxWidth(c.Options), (c.Options["theme"] == "color"))
 	c.PageState.Add(pg)
 	c.SetPercentRead()
 	c.ClearMessage()
@@ -1117,7 +1123,7 @@ func (c *client) handleWeb(u Url) {
 				return
 			}
 			pg := MakePage(u, page.Content, page.Links)
-			pg.WrapContent(c.Width-1, (c.Options["theme"] == "color"))
+			pg.WrapContent(c.Width-1, getMaxWidth(c.Options), (c.Options["theme"] == "color"))
 			c.PageState.Add(pg)
 			c.SetPercentRead()
 			c.ClearMessage()
@@ -1258,3 +1264,16 @@ func updateTimeouts(timeoutString string) error {
 
 	return nil
 }
+
+// getMaxWidth looks through the given options map and will safely return a max width to render
+// if the option is missing or malformed, it will default to 100.  A sane minimum of 10 is enforced.
+func getMaxWidth(options map[string]string) int {
+	out, err := strconv.Atoi(options["maxwidth"])
+	if err != nil {
+		out = 100
+	}
+	if out < 10 {
+		out = 10
+	}
+	return out
+}
\ No newline at end of file
